==> taler-wallet-v0.10.6.tar.gz: taler-wallet-v0.10.6/packages/taler-harness/src/integrationtests/test-claim-loop.ts <==
/*
 This file is part of GNU Taler
 (C) 2020 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 * Imports.
 */
import { WalletApiOperation } from "@gnu-taler/taler-wallet-core";
import { URL } from "url";
import { GlobalTestState } from "../harness/harness.js";
import {
  createSimpleTestkudosEnvironmentV2,
  withdrawViaBankV2,
} from "../harness/helpers.js";
import { MerchantApiClient } from "@gnu-taler/taler-util";

/**
 * Run test for the merchant's order lifecycle.
 *
 * FIXME: Is this test still necessary?  We initially wrote if to confirm/document
 * assumptions about how the merchant should work.
 */
export async function runClaimLoopTest(t: GlobalTestState) {
  // Set up test environment

  const { walletClient, bank, exchange, merchant } =
    await createSimpleTestkudosEnvironmentV2(t);

  await withdrawViaBankV2(t, {
    walletClient,
    bank,
    exchange,
    amount: "TESTKUDOS:20",
  });

  const merchantClient = new MerchantApiClient(merchant.makeInstanceBaseUrl());

  // Set up order.
  const orderResp = await merchantClient.createOrder({
    order: {
      summary: "Buy me!",
      amount: "TESTKUDOS:5",
      fulfillment_url: "taler://fulfillment-success/thx",
    },
  });

  // Query private order status before claiming it.
  let orderStatusBefore = await merchantClient.queryPrivateOrderStatus({
    orderId: orderResp.order_id,
  });
  t.assertTrue(orderStatusBefore.order_status === "unpaid");
  let statusUrlBefore = new URL(orderStatusBefore.order_status_url);

  // Make wallet claim the unpaid order.
  t.assertTrue(orderStatusBefore.order_status === "unpaid");
  const talerPayUri = orderStatusBefore.taler_pay_uri;
  await walletClient.call(WalletApiOperation.PreparePayForUri, {
    talerPayUri,
  });

  // Query private order status after claiming it.
  let orderStatusAfter = await merchantClient.queryPrivateOrderStatus({
    orderId: orderResp.order_id,
  });
  t.assertTrue(orderStatusAfter.order_status === "claimed");

  await t.shutdown();
}

runClaimLoopTest.suites = ["merchant"];

==> taler-wallet-v0.13.1.tar.gz: taler-wallet-v0.13.1/packages/taler-harness/src/integrationtests/test-claim-loop.ts <==
/*
 This file is part of GNU Taler
 (C) 2020 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 * Imports.
 */
import { WalletApiOperation } from "@gnu-taler/taler-wallet-core";
import { URL } from "url";
import { GlobalTestState } from "../harness/harness.js";
import {
  createSimpleTestkudosEnvironmentV3,
  withdrawViaBankV3,
} from "../harness/helpers.js";
import { MerchantApiClient } from "@gnu-taler/taler-util";

/**
 * Run test for the merchant's order lifecycle.
 *
 * FIXME: Is this test still necessary?  We initially wrote if to confirm/document
 * assumptions about how the merchant should work.
 */
export async function runClaimLoopTest(t: GlobalTestState) {
  // Set up test environment

  const { walletClient, bankClient, exchange, merchant } =
    await createSimpleTestkudosEnvironmentV3(t);

  await withdrawViaBankV3(t, {
    walletClient,
    bankClient,
    exchange,
    amount: "TESTKUDOS:20",
  });

  const merchantClient = new MerchantApiClient(merchant.makeInstanceBaseUrl());

  // Set up order.
  const orderResp = await merchantClient.createOrder({
    order: {
      summary: "Buy me!",
      amount: "TESTKUDOS:5",
      fulfillment_url: "taler://fulfillment-success/thx",
    },
  });

  // Query private order status before claiming it.
  let orderStatusBefore = await merchantClient.queryPrivateOrderStatus({
    orderId: orderResp.order_id,
  });
  t.assertTrue(orderStatusBefore.order_status === "unpaid");
  let statusUrlBefore = new URL(orderStatusBefore.order_status_url);

  // Make wallet claim the unpaid order.
  t.assertTrue(orderStatusBefore.order_status === "unpaid");
  const talerPayUri = orderStatusBefore.taler_pay_uri;
  await walletClient.call(WalletApiOperation.PreparePayForUri, {
    talerPayUri,
  });

  // Query private order status after claiming it.
  let orderStatusAfter = await merchantClient.queryPrivateOrderStatus({
    orderId: orderResp.order_id,
  });
  t.assertTrue(orderStatusAfter.order_status === "claimed");

  await t.shutdown();
}

runClaimLoopTest.suites = ["merchant"];
